@@ -1,3 +1,4 @@
+mod coordinates;
 mod filter;
 mod icon;
 mod identifier;
@@ -21,6 +22,7 @@ mod step_mode;
 mod store;
 mod workflow_duration;
 
+pub use coordinates::Coordinates;
 pub use filter::Filter;
 pub use icon::Icon;
 pub use identifier::Identifier;
